AgoraSharedUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getBool(
String key, {bool defaultValue = false}) → Future< bool> -
getDouble(
String key) → Future< double> -
getInt(
String key) → Future< int> -
getString(
String key) → Future< String> -
remove(
String key) → dynamic - 清除本地缓存
-
setBool(
String key, bool value) → Future< bool> - 添加/获取本地缓存
-
setDouble(
String key, double value) → Future< bool> -
setInt(
String key, int value) → Future< bool> -
setString(
String key, String value) → Future< bool>